#
# spec file for package presenterm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           presenterm
Version:        0.7.0+0
Release:        1.1
Summary:        A terminal slideshow tool
License:        BSD-2-Clause
URL:            https://github.com/mfontanini/presenterm
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging

%description
A terminal slideshow tool.

%prep
%autosetup -p1 -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%check
%{cargo_test}

%files
%{_bindir}/%{name}

%changelog
* Mon Mar  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.7.0:
  New features:
  * Add color to prefix in block quote (#218).
  * Allow having code blocks without background (#215 #216).
  * Allow validating whether presentation overflows terminal (#209 #211).
  * Add parameter to list themes (#207).
  * Add catppuccin themes (#197 #205 #206)
  * Detect konsole terminal emulator (#204).
  * Allow customizing slide title style (#201).
  Fixes:
  * Don't crash in present mode (#210).
  * Set colors properly before displaying an error (#212).
  Improvements:
  * Suggest a tool is missing when spawning returns ENOTFOUND (#221).
  * Sort input file list (#202).
  * Add more example presentations (#217).
  * Add Scoop to package managers (#200).
  * Remove support for uncommon image formats (#208).
* Mon Feb 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  * Don't escape symbols in block quotes (#195).
  * Respect XDG_CONFIG_HOME when loading configuration files and
  custom themes (#193).
* Sat Feb 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  Breaking changes:
  * The default configuration file and custom themes paths have been
    changed in Windows and macOS to be compliant to where
    those platforms store these types of files. See the configuration
    guide to learn more.
  New features:
  * Add f keys, tab, and backspace as possible bindings (#188).
  * Add support for multiline block quotes (#184).
  * Use theme color as background on ascii-blocks mode images (#182).
  * Blend ascii-blocks image semi-transparent borders (#185).
  * Respect Windows/macOS config paths for configuration (#181).
  * Allow making front matter strict parsing optional (#190).
  Fixes:
  * Don't add an extra line after an end slide shorthand (#187).
  * Don't clear input state on key release event (#183).
* Sat Jan 27 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  New features:
  * Support images on Windows (#120).
  * Support animated gifs on kitty terminal (#157 #161).
  * Support images on tmux running in kitty terminal (#166).
  * Improve sixel support (#169 #172).
  * Use synchronized updates to remove flickering when switching slides (#156).
  * Add newlines command (#167).
  * Detect image protocol instead of relying on viuer (#160).
  * Turn documentation into mdbook (#141 #147)
  * Allow using thematic breaks to end slides (#138).
  * Allow specifying the preferred image protocol via --image-protocol / config file (#136 #170).
  * Add slide index modal (#128 #139 #133 #158).
  * Allow defining custom keybindings in config file (#132 #155).
  * Add key bindings modal (#152).
  * Prioritize CLI args --theme over anything else (#116).
  * Allow enabling automatic list pauses (#106 #109 #110).
  * Allow passing in config file path via CLI arg (#174).
  Fixes:
  * Shrink columns layout dimensions correctly when shrinking left (#113).
  * Explicitly set execution output foreground color in built-in themes (#122).
  * Detect sixel early and fallback to ascii blocks properly (#135).
  * Exit with a clap error on missing path (#150).
  * Don't blow up if presentation file temporarily disappears (#154).
  * Parse front matter properly in presence of \r\n (#162).
  * Don't preload graphics mode when generating pdf metadata (#168).
  * Ignore key release events (#119).
  Improvements:
  * Validate that config file contains the right attributes (#107).
  * Display first presentation load error as any other (#118).
  * Add hashes for windows artifacts (#126).
  * Remove arch packaging files (#111).
  * Lower CPU and memory usage when displaying images (#157).
* Fri Dec 22 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  * Cause an error if an unknown field name is found on a theme, config
    file, or front matter (#102).
  * Explicitly disable kitty/iterm protocols when printing images in export
    PDF mode as this was causing PDF generation in macOS to fail (#101).
* Sun Dec 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  * Add support for all of bat's code highlighting themes (#67).
  * Add terminal-dark and terminal-light themes that preserve
    the terminal's colors and background (#68 #69).
  * Allow placing themes in $HOME/.config/presenterm/themes
    to make them available automatically as if they were
    built-in themes (#73).
  * Allow configuring the default theme in
    $HOME/.config/presenterm/config.yaml (#74).
  * Add support for rendering LaTeX and typst code blocks
    automatically as images (#75 #76 #79 #81).
  * Add syntax highlighting support for nix and diff (#78 #82).
  * Add comment command to jump into the middle of a slide (#86).
  * Add configuration option to have implicit slide ends (#87 #89).
  * Add configuration option to have custom comment-command prefix (#91).
* Fri Nov 24 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.3.0:
  New features:
  * Support more languages in code blocks thanks to bat's syntax
    sets (#21 #53).
  * Add shell script executable code blocks (#17).
  * Allow exporting presentation to PDF (#43 #60).
  * Pauses no longer create new slides (#18 #25 #34 #42).
  * Allow display code block line numbers (#46).
  * Allow code block selective line highlighting (#48).
  * Allow code block dynamic line highlighting (#49).
  * Support animated gifs when using the iterm2 image protocol (#56).
  * Nix flake packaging (#11 #27).
  * Arch repo packaging (#10).
  * Ignore vim-like code folding tags in comments.
  * Add keybinding to refresh assets in presentation (#38).
  * Template style footer is now one row above bottom (#39).
  * Add light theme (#55).
  Fixes:
  * Don't crash on Windows when terminal window size can't be found (#14).
  * Don't reset numbers on ordered lists when using pauses in between (#19).
  * Show proper line number when parsing a comment command fails (#29 #40).
  * Don't reset the default footer when overriding theme in
    presentation without setting footer (#52).
  * Don't let code blocks/block quotes that don't fit on the screen
    cause images to overlap with text (#57).
* Thu Oct 19 2023 Michael Vetter <jubalh@iodoru.org>
- Update to 0.2.1:
  * Binary artifacts are now automatically generated when a new
    release is done #5
* Wed Oct 18 2023 Michael Vetter <jubalh@iodoru.org>
- Initial package of presenterm 0.2.0 for openSUSE
